@@ -56,7 +56,7 @@ class LazyConfig(MutableMapping):
 
     @property
     def path(self):
-        return os.path.expanduser("~/.config/{}/config.toml".format(self._app_name))
+        return os.path.expanduser(f"~/.config/{self._app_name}/config.toml")
 
     def __getitem__(self, key):
         if not self.loaded:
