@@ -4,7 +4,8 @@ import attr
 from dateutil.parser import isoparse
 
 from git_pr_branch.config import conf
-from .base import ServerRepo, PullRequest
+
+from .base import PullRequest, ServerRepo
 
 
 @attr.s(auto_attribs=True)
@@ -43,13 +44,17 @@ class Review:
 
     @classmethod
     def from_github(cls, data):
+        try:
+            datetime = isoparse(data["submitted_at"])
+        except KeyError:
+            datetime = None
         return cls(
             id=data["id"],
             commit_id=data["commit_id"],
             html_url=data["html_url"],
             username=data["user"]["login"],
             state=data["state"],
-            datetime=isoparse(data["submitted_at"]),
+            datetime=datetime,
             body=data["body"],
         )
 
@@ -97,3 +102,7 @@ class GithubRepo(ServerRepo):
 
     def _get_pull(self, number):
         return self.call_api(f"/pulls/{number}")
+
+    def get_default_branch_name(self):
+        data = self.call_api("/")
+        return data["default_branch"]
