@@ -1,4 +1,4 @@
-from subprocess import run, PIPE, DEVNULL
+from subprocess import DEVNULL, PIPE, run
 
 import click
 
@@ -13,7 +13,7 @@ def get_cmd(*args, hide_stderr=False):
         check=True,
         stdout=PIPE,
         stderr=DEVNULL if hide_stderr else None,
-        universal_newlines=True,
+        text=True,
     ).stdout
     if output.endswith("\n"):
         output = output[:-1]
