@@ -1,4 +1,4 @@
-from git_pr_branch.repo import GitRemote, GitBranch
+from git_pr_branch.repo import GitBranch, GitRemote
 
 
 def get_remote_for_pr(repo, pr):
